# Wagtail Advanced Form Builder

![Form fields](./docs/screenshots/waf-form-fields.png)

# About

Wagtail Advanced Form Builder is an extension on top of Wagtail's in-built Form Builder. It provides the ability to 
create forms with conditional logic.

# Documentation

The documentation for using and developing with Wagtail Advanced Form Builder can be found at https://wagtail-advanced-form-builder.readthedocs.io/en/latest/

# Getting Help

Please report bugs or issues using the [Issue Tracker](https://github.com/octavenz/wagtail-advanced-form-builder/issues) 

# Authors

* Richard Blake ([Octave](https://octave.nz))

# License

This project is licensed under the BSD License - see the [LICENSE file](./LICENCE) for details

